Class: Google::Apis::CloudtasksV2::StackdriverLoggingConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2::StackdriverLoggingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2/classes.rb,
lib/google/apis/cloudtasks_v2/representations.rb,
lib/google/apis/cloudtasks_v2/representations.rb
Overview
Configuration options for writing logs to Stackdriver Logging.
Instance Attribute Summary collapse
-
#sampling_ratio ⇒ Float
Specifies the fraction of operations to write to Stackdriver Logging.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StackdriverLoggingConfig
constructor
A new instance of StackdriverLoggingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StackdriverLoggingConfig
Returns a new instance of StackdriverLoggingConfig.
1542 1543 1544 |
# File 'lib/google/apis/cloudtasks_v2/classes.rb', line 1542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sampling_ratio ⇒ Float
Specifies the fraction of operations to write to Stackdriver Logging. This field may contain any value between 0.0
and 1.0, inclusive. 0.0 is the default and means that no operations are logged.
Corresponds to the JSON property samplingRatio
1540 1541 1542 |
# File 'lib/google/apis/cloudtasks_v2/classes.rb', line 1540 def sampling_ratio @sampling_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1547 1548 1549 |
# File 'lib/google/apis/cloudtasks_v2/classes.rb', line 1547 def update!(**args) @sampling_ratio = args[:sampling_ratio] if args.key?(:sampling_ratio) end |