Class: Google::Apis::CloudtasksV2::StackdriverLoggingConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2::StackdriverLoggingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2/classes.rb,
lib/google/apis/cloudtasks_v2/representations.rb,
lib/google/apis/cloudtasks_v2/representations.rb
Overview
Configuration options for writing logs to Stackdriver Logging.
Instance Attribute Summary collapse
-
#sampling_ratio ⇒ Float
Specifies the fraction of operations to write to Stackdriver Logging.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StackdriverLoggingConfig
constructor
A new instance of StackdriverLoggingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StackdriverLoggingConfig
Returns a new instance of StackdriverLoggingConfig.
1539 1540 1541 |
# File 'lib/google/apis/cloudtasks_v2/classes.rb', line 1539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sampling_ratio ⇒ Float
Specifies the fraction of operations to write to Stackdriver Logging. This field may contain any value between 0.0
and 1.0, inclusive. 0.0 is the default and means that no operations are logged.
Corresponds to the JSON property samplingRatio
1537 1538 1539 |
# File 'lib/google/apis/cloudtasks_v2/classes.rb', line 1537 def sampling_ratio @sampling_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1544 1545 1546 |
# File 'lib/google/apis/cloudtasks_v2/classes.rb', line 1544 def update!(**args) @sampling_ratio = args[:sampling_ratio] if args.key?(:sampling_ratio) end |